PyXMake Developer Guide: PyXMake.Build.Make.PyInstaller Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.PyInstaller Class Reference

Base class for all PyInstaller build events. More...

Inheritance diagram for PyXMake.Build.Make.PyInstaller:

## Public Member Functions
def | __init__ (self, args, kwargs)
def | Encryption (self, encrypt, kwargs)
def | Preprocessing (self, cmdstring='')
def | Build (self, mode="onefile", kwargs)
def | create (self, kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| MakeObjectKind
| String identifier of current instance. More...
| buildtype
| libs
| libdirs
| incdirs
| key_string
| precmd
| Command executed during pre-build event. More...
| makecmd
| temps
| verbose
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Base class for all PyInstaller build events.

    Inherited class to build projects using PyInstaller.

Inherited from Make.

Definition at line 1015 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.PyInstaller.__init__ | ( |  | self,
|  |  | args,
|  |  | kwargs
| ) |  |

    Initialization of PyInstaller class object.

    @note Creates stand-alone application of Python scripts using PyInstaller.

Definition at line 1019 of file Make.py.

## Member Function Documentation

## ◆ Build()

def PyXMake.Build.Make.PyInstaller.Build | ( |  | self,
|  |  | mode = `"onefile"`,
|  |  | kwargs
| ) |  |

    Switch build mode. Defaults to one single file.

Definition at line 1063 of file Make.py.

## ◆ create()

def PyXMake.Build.Make.PyInstaller.create | ( |  | self,
|  |  | kwargs
| ) |  |

    Execute make command

Definition at line 1199 of file Make.py.

## ◆ Encryption()

def PyXMake.Build.Make.PyInstaller.Encryption | ( |  | self,
|  |  | encrypt,
|  |  | kwargs
| ) |  |

    Encrypt byte-code by using user-supplied or randomly generated key.

    @author: garb_ma
    @param encrypt: Boolean

Definition at line 1042 of file Make.py.

## ◆ Preprocessing()

def PyXMake.Build.Make.PyInstaller.Preprocessing | ( |  | self,
|  |  | cmdstring = `''`
| ) |  |

    Assemble command string for the pre-build event.

Definition at line 1053 of file Make.py.

## Member Data Documentation

## ◆ MakeObjectKind

PyXMake.Build.Make.PyInstaller.MakeObjectKind

String identifier of current instance.

Definition at line 1027 of file Make.py.

## ◆ precmd

PyXMake.Build.Make.PyInstaller.precmd

Command executed during pre-build event.

Definition at line 1060 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py